@@ -1,52 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
-**
-** This file is part of the ActiveQt framework of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:BSD$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** BSD License Usage
-** Alternatively, you may use this file under the terms of the BSD license
-** as follows:
-**
-** "Redistribution and use in source and binary forms, with or without
-** modification, are permitted provided that the following conditions are
-** met:
-**   * Redistributions of source code must retain the above copyright
-**     notice, this list of conditions and the following disclaimer.
-**   * Redistributions in binary form must reproduce the above copyright
-**     notice, this list of conditions and the following disclaimer in
-**     the documentation and/or other materials provided with the
-**     distribution.
-**   * Neither the name of The Qt Company Ltd nor the names of its
-**     contributors may be used to endorse or promote products derived
-**     from this software without specific prior written permission.
-**
-**
-** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2015 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause
 
 #ifndef NOMINMAX
 #  define NOMINMAX
@@ -447,7 +400,7 @@ bool QVariantToVARIANT(const QVariant &var, VARIANT &arg, const QByteArray &type
     case QMetaType::QVariantList:
         {
             const auto list = qvar.toList();
-            const int count = list.count();
+            const qsizetype count = list.size();
             VARTYPE vt = VT_VARIANT;
             int listType = QMetaType::QVariant;
             if (!typeName.isEmpty() && typeName.startsWith("QList<")) {
@@ -487,7 +440,7 @@ bool QVariantToVARIANT(const QVariant &var, VARIANT &arg, const QByteArray &type
             // treated as a 2D array. The column count is taken from the 1st element.
             if (count) {
                 QVariantList col = list.at(0).toList();
-                int maxColumns = col.count();
+                qsizetype maxColumns = col.size();
                 if (maxColumns) {
                     is2D = true;
                     SAFEARRAYBOUND rgsabound[2] = { {0, 0}, {0, 0} };
@@ -498,7 +451,7 @@ bool QVariantToVARIANT(const QVariant &var, VARIANT &arg, const QByteArray &type
                     for (LONG i = 0; i < count; ++i) {
                         rgIndices[0] = i;
                         QVariantList columns = list.at(i).toList();
-                        int columnCount = qMin(maxColumns, columns.count());
+                        qsizetype columnCount = qMin(maxColumns, columns.size());
                         for (LONG j = 0;  j < columnCount; ++j) {
                             const QVariant &elem = columns.at(j);
                             VariantInit(&variant);
@@ -541,7 +494,7 @@ bool QVariantToVARIANT(const QVariant &var, VARIANT &arg, const QByteArray &type
     case QMetaType::QStringList:
         {
             const QStringList list = qvar.toStringList();
-            const int count = list.count();
+            const qsizetype count = list.size();
             SAFEARRAY *array = SafeArrayCreateVector(VT_BSTR, 0, count);
             for (LONG index = 0; index < count; ++index) {
                 QString elem = list.at(index);
@@ -568,7 +521,7 @@ bool QVariantToVARIANT(const QVariant &var, VARIANT &arg, const QByteArray &type
     case QMetaType::QByteArray:
         {
             const QByteArray bytes = qvar.toByteArray();
-            const uint count = bytes.count();
+            const uint count = static_cast<uint>(bytes.size());
             SAFEARRAY *array = SafeArrayCreateVector(VT_UI1, 0, count);
             if (count) {
                 const char *data = bytes.constData();
@@ -749,6 +702,25 @@ bool QVariantToVARIANT(const QVariant &var, VARIANT &arg, const QByteArray &type
     return true;
 }
 
+#ifdef QAX_SERVER
+static QVariant axServer(IUnknown *unknown, const QByteArray &typeName)
+{
+    IAxServerBase *iface = nullptr;
+    if (unknown && typeName != "IDispatch*" && typeName != "IUnknown*")
+        unknown->QueryInterface(IID_IAxServerBase, reinterpret_cast<void**>(&iface));
+    if (iface == nullptr)
+        return {};
+
+    auto *qObj = iface->qObject();
+    iface->Release();
+    QByteArray pointerType = qObj ? QByteArray(qObj->metaObject()->className()) + '*' : typeName;
+    QMetaType pointerMetaType = QMetaType::fromName(pointerType);
+    if (pointerMetaType.id() == QMetaType::UnknownType)
+        pointerMetaType = QMetaType(qRegisterMetaType<QObject *>(pointerType));
+    return QVariant(pointerMetaType, &qObj);
+}
+#endif // QAX_SERVER
+
 #undef QVARIANT_TO_VARIANT_POD
 
 /*
@@ -960,17 +932,8 @@ QVariant VARIANTToQVariant(const VARIANT &arg, const QByteArray &typeName, int t
                 }
             } else {
 #ifdef QAX_SERVER
-                IAxServerBase *iface = 0;
-                if (disp && typeName != "IDispatch*")
-                    disp->QueryInterface(IID_IAxServerBase, reinterpret_cast<void**>(&iface));
-                if (iface) {
-                    QObject *qObj = iface->qObject();
-                    iface->Release();
-                    QByteArray pointerType = qObj ? QByteArray(qObj->metaObject()->className()) + '*' : typeName;
-                    QMetaType pointerMetaType = QMetaType::fromName(pointerType);
-                    if (pointerMetaType.id() == QMetaType::UnknownType)
-                        pointerMetaType = QMetaType(qRegisterMetaType<QObject *>(pointerType));
-                    var = QVariant(pointerMetaType, &qObj);
+                if (auto axs = axServer(disp, typeName); axs.isValid()) {
+                    var = axs;
                 } else
 #endif
                 {
@@ -1014,6 +977,10 @@ QVariant VARIANTToQVariant(const VARIANT &arg, const QByteArray &typeName, int t
             else
                 unkn = arg.punkVal;
             var.setValue(unkn);
+#ifdef QAX_SERVER
+            if (auto axs = axServer(unkn, typeName); axs.isValid())
+                var = axs;
+#endif
         }
         break;
     case VT_ARRAY|VT_VARIANT:
